"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
exports.defaultSchemaLoader = async (schemaConfig) => {
    const { requestOpts, uri, introspectionOptions } = schemaConfig;
    const fetchResult = await fetch(uri, {
        method: requestOpts?.method ?? 'post',
        body: JSON.stringify({
            query: graphql_1.getIntrospectionQuery(introspectionOptions),
            operationName: 'IntrospectionQuery',
        }),
        credentials: 'omit',
        headers: requestOpts?.headers || {
            'Content-Type': 'application/json',
        },
        ...requestOpts,
    });
    const introspectionResponse = await fetchResult.json();
    return introspectionResponse?.data;
};
function defaultSchemaBuilder(response, buildSchemaOptions) {
    if (!response) {
        throw Error('Empty schema response');
    }
    if ('__schema' in response) {
        return graphql_1.buildClientSchema(response, buildSchemaOptions);
    }
    return graphql_1.buildASTSchema(response, buildSchemaOptions);
}
exports.defaultSchemaBuilder = defaultSchemaBuilder;
//# sourceMappingURL=schemaLoader.js.map